@@ -28,7 +28,7 @@ class RemoteLogging(StubClientMixin):
         self.local_logging = None
         self.log_both = False
 
-    def init(self, opts):
+    def init(self, opts, _extra_args=[]):
         self.log_both = (opts.remote_logging or "").lower()=="both"
         self.client_supports_remote_logging = self.log_both or parse_bool("remote-logging", opts.remote_logging)
 
